===============================
hipyschool
===============================


.. image:: https://img.shields.io/pypi/v/hipyschool.svg
        :target: https://pypi.python.org/pypi/hipyschool

.. image:: https://img.shields.io/travis/sophilabs/hipyschool.svg
        :target: https://travis-ci.org/sophilabs/hipyschool

.. image:: https://pyup.io/repos/github/sophilabs/hipyschool/shield.svg
     :target: https://pyup.io/repos/github/sophilabs/hipyschool/
     :alt: Updates


A pyschool story for learning regular expressions.


* Free software: MIT license


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

